# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'presence_walkSpeed_0.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1366, 768)
        font = QtGui.QFont()
        font.setFamily("Calibri")
        font.setPointSize(12)
        Form.setFont(font)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.s1 = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.s1.sizePolicy().hasHeightForWidth())
        self.s1.setSizePolicy(sizePolicy)
        self.s1.setObjectName("s1")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.s1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.s1_lb_1 = QtWidgets.QLabel(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_lb_1.sizePolicy().hasHeightForWidth())
        self.s1_lb_1.setSizePolicy(sizePolicy)
        self.s1_lb_1.setObjectName("s1_lb_1")
        self.gridLayout_2.addWidget(self.s1_lb_1, 3, 0, 1, 5)
        self.s1_com_1 = QtWidgets.QComboBox(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_com_1.sizePolicy().hasHeightForWidth())
        self.s1_com_1.setSizePolicy(sizePolicy)
        self.s1_com_1.setObjectName("s1_com_1")
        self.gridLayout_2.addWidget(self.s1_com_1, 1, 3, 1, 2)
        self.s1_lb = QtWidgets.QLabel(self.s1)
        self.s1_lb.setObjectName("s1_lb")
        self.gridLayout_2.addWidget(self.s1_lb, 1, 0, 1, 1)
        self.s1_lcd_1 = QtWidgets.QLCDNumber(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.s1_lcd_1.sizePolicy().hasHeightForWidth())
        self.s1_lcd_1.setSizePolicy(sizePolicy)
        self.s1_lcd_1.setObjectName("s1_lcd_1")
        self.gridLayout_2.addWidget(self.s1_lcd_1, 5, 2, 1, 3)
        self.label_6 = QtWidgets.QLabel(self.s1)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 5, 0, 1, 2)
        self.s1_bt_2 = QtWidgets.QPushButton(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_bt_2.sizePolicy().hasHeightForWidth())
        self.s1_bt_2.setSizePolicy(sizePolicy)
        self.s1_bt_2.setObjectName("s1_bt_2")
        self.gridLayout_2.addWidget(self.s1_bt_2, 2, 3, 1, 1)
        self.raw_broswer = QtWidgets.QTextBrowser(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(8)
        sizePolicy.setHeightForWidth(self.raw_broswer.sizePolicy().hasHeightForWidth())
        self.raw_broswer.setSizePolicy(sizePolicy)
        self.raw_broswer.setObjectName("raw_broswer")
        self.gridLayout_2.addWidget(self.raw_broswer, 4, 0, 1, 5)
        self.s1_bt_3 = QtWidgets.QPushButton(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_bt_3.sizePolicy().hasHeightForWidth())
        self.s1_bt_3.setSizePolicy(sizePolicy)
        self.s1_bt_3.setObjectName("s1_bt_3")
        self.gridLayout_2.addWidget(self.s1_bt_3, 2, 4, 1, 1)
        self.s1_bt_1 = QtWidgets.QPushButton(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_bt_1.sizePolicy().hasHeightForWidth())
        self.s1_bt_1.setSizePolicy(sizePolicy)
        self.s1_bt_1.setObjectName("s1_bt_1")
        self.gridLayout_2.addWidget(self.s1_bt_1, 0, 4, 1, 1)
        self.gridLayout.addWidget(self.s1, 0, 0, 1, 2)
        self.label_5 = QtWidgets.QLabel(Form)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 1, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(Form)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 3, 0, 1, 1)
        self.s1_line_3 = QtWidgets.QLineEdit(Form)
        self.s1_line_3.setObjectName("s1_line_3")
        self.gridLayout.addWidget(self.s1_line_3, 3, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(Form)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.s1_line_2 = QtWidgets.QLineEdit(Form)
        self.s1_line_2.setObjectName("s1_line_2")
        self.gridLayout.addWidget(self.s1_line_2, 2, 1, 1, 1)
        self.s1_line_1 = QtWidgets.QLineEdit(Form)
        self.s1_line_1.setObjectName("s1_line_1")
        self.gridLayout.addWidget(self.s1_line_1, 1, 1, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(11)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.s2_plot = GraphicsLayoutWidget(self.tab)
        self.s2_plot.setObjectName("s2_plot")
        self.gridLayout_3.addWidget(self.s2_plot, 5, 0, 1, 7)
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.tab)
        self.label_7.setObjectName("label_7")
        self.gridLayout_3.addWidget(self.label_7, 9, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.tab)
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 8, 0, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.tab)
        self.label_9.setObjectName("label_9")
        self.gridLayout_3.addWidget(self.label_9, 10, 0, 1, 1)
        self.s2_line_info = QtWidgets.QLineEdit(self.tab)
        self.s2_line_info.setObjectName("s2_line_info")
        self.gridLayout_3.addWidget(self.s2_line_info, 4, 0, 1, 4)
        self.label_13 = QtWidgets.QLabel(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setObjectName("label_13")
        self.gridLayout_3.addWidget(self.label_13, 1, 0, 1, 1)
        self.s2_com_1 = QtWidgets.QComboBox(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.s2_com_1.sizePolicy().hasHeightForWidth())
        self.s2_com_1.setSizePolicy(sizePolicy)
        self.s2_com_1.setObjectName("s2_com_1")
        self.s2_com_1.addItem("")
        self.s2_com_1.addItem("")
        self.s2_com_1.addItem("")
        self.s2_com_1.addItem("")
        self.s2_com_1.addItem("")
        self.gridLayout_3.addWidget(self.s2_com_1, 1, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.tab)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 2, 0, 1, 1)
        self.s2_line_3 = QtWidgets.QLineEdit(self.tab)
        self.s2_line_3.setObjectName("s2_line_3")
        self.gridLayout_3.addWidget(self.s2_line_3, 8, 1, 1, 3)
        self.s2_line_4 = QtWidgets.QLineEdit(self.tab)
        self.s2_line_4.setObjectName("s2_line_4")
        self.gridLayout_3.addWidget(self.s2_line_4, 9, 1, 1, 3)
        self.s2_line_5 = QtWidgets.QLineEdit(self.tab)
        self.s2_line_5.setObjectName("s2_line_5")
        self.gridLayout_3.addWidget(self.s2_line_5, 10, 1, 1, 3)
        self.s2_line_2 = QtWidgets.QLineEdit(self.tab)
        self.s2_line_2.setObjectName("s2_line_2")
        self.gridLayout_3.addWidget(self.s2_line_2, 2, 1, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.tab)
        self.label_15.setObjectName("label_15")
        self.gridLayout_3.addWidget(self.label_15, 2, 2, 1, 1)
        self.s2_bt_1 = QtWidgets.QPushButton(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.s2_bt_1.sizePolicy().hasHeightForWidth())
        self.s2_bt_1.setSizePolicy(sizePolicy)
        self.s2_bt_1.setObjectName("s2_bt_1")
        self.gridLayout_3.addWidget(self.s2_bt_1, 1, 3, 1, 1)
        self.s2_bt_2 = QtWidgets.QPushButton(self.tab)
        self.s2_bt_2.setObjectName("s2_bt_2")
        self.gridLayout_3.addWidget(self.s2_bt_2, 1, 4, 1, 1)
        self.s2_bt_3 = QtWidgets.QPushButton(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.s2_bt_3.sizePolicy().hasHeightForWidth())
        self.s2_bt_3.setSizePolicy(sizePolicy)
        self.s2_bt_3.setObjectName("s2_bt_3")
        self.gridLayout_3.addWidget(self.s2_bt_3, 2, 4, 1, 1)
        self.s2_line_1 = QtWidgets.QLineEdit(self.tab)
        self.s2_line_1.setObjectName("s2_line_1")
        self.gridLayout_3.addWidget(self.s2_line_1, 0, 1, 1, 4)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.s2_plot_2 = GraphicsLayoutWidget(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(9)
        sizePolicy.setHeightForWidth(self.s2_plot_2.sizePolicy().hasHeightForWidth())
        self.s2_plot_2.setSizePolicy(sizePolicy)
        self.s2_plot_2.setObjectName("s2_plot_2")
        self.gridLayout_4.addWidget(self.s2_plot_2, 1, 0, 1, 6)
        self.widget_2 = QtWidgets.QWidget(self.tab_2)
        self.widget_2.setObjectName("widget_2")
        self.gridLayout_4.addWidget(self.widget_2, 2, 5, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_11.sizePolicy().hasHeightForWidth())
        self.label_11.setSizePolicy(sizePolicy)
        self.label_11.setObjectName("label_11")
        self.gridLayout_4.addWidget(self.label_11, 0, 0, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.label_10.sizePolicy().hasHeightForWidth())
        self.label_10.setSizePolicy(sizePolicy)
        self.label_10.setObjectName("label_10")
        self.gridLayout_4.addWidget(self.label_10, 2, 0, 1, 1)
        self.s2_t2_browser = QtWidgets.QTextBrowser(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(9)
        sizePolicy.setHeightForWidth(self.s2_t2_browser.sizePolicy().hasHeightForWidth())
        self.s2_t2_browser.setSizePolicy(sizePolicy)
        self.s2_t2_browser.setObjectName("s2_t2_browser")
        self.gridLayout_4.addWidget(self.s2_t2_browser, 3, 0, 2, 2)
        self.label_12 = QtWidgets.QLabel(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_12.sizePolicy().hasHeightForWidth())
        self.label_12.setSizePolicy(sizePolicy)
        self.label_12.setObjectName("label_12")
        self.gridLayout_4.addWidget(self.label_12, 3, 2, 1, 1)
        self.s2_t2_lcd_1 = QtWidgets.QLCDNumber(self.tab_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s2_t2_lcd_1.sizePolicy().hasHeightForWidth())
        self.s2_t2_lcd_1.setSizePolicy(sizePolicy)
        self.s2_t2_lcd_1.setObjectName("s2_t2_lcd_1")
        self.gridLayout_4.addWidget(self.s2_t2_lcd_1, 3, 3, 1, 2)
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout.addWidget(self.tabWidget, 0, 2, 4, 1)

        self.retranslateUi(Form)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.s1.setTitle(_translate("Form", "裝置設置"))
        self.s1_lb_1.setText(_translate("Form", "裝置資訊"))
        self.s1_lb.setText(_translate("Form", "裝置名稱"))
        self.label_6.setText(_translate("Form", "當前位置 (m)"))
        self.s1_bt_2.setText(_translate("Form", "connect"))
        self.s1_bt_3.setText(_translate("Form", "disconnect"))
        self.s1_bt_1.setText(_translate("Form", "檢查裝置"))
        self.label_5.setText(_translate("Form", "使用者"))
        self.label_4.setText(_translate("Form", "上次存取時間:"))
        self.label_3.setText(_translate("Form", "當前時間"))
        self.s1_line_1.setText(_translate("Form", "defaultUser"))
        self.label.setText(_translate("Form", "紀錄名稱:"))
        self.label_7.setText(_translate("Form", "結束時間"))
        self.label_2.setText(_translate("Form", "開始時間"))
        self.label_9.setText(_translate("Form", "紀錄人數"))
        self.label_13.setText(_translate("Form", "預備時間(sec)："))
        self.s2_com_1.setItemText(0, _translate("Form", "1"))
        self.s2_com_1.setItemText(1, _translate("Form", "5"))
        self.s2_com_1.setItemText(2, _translate("Form", "7"))
        self.s2_com_1.setItemText(3, _translate("Form", "10"))
        self.s2_com_1.setItemText(4, _translate("Form", "15"))
        self.label_8.setText(_translate("Form", "底端距離(m)："))
        self.s2_line_5.setText(_translate("Form", "1人"))
        self.s2_line_2.setText(_translate("Form", "5.85"))
        self.label_15.setText(_translate("Form", "請加小數點"))
        self.s2_bt_1.setText(_translate("Form", "start"))
        self.s2_bt_2.setText(_translate("Form", "stop"))
        self.s2_bt_3.setText(_translate("Form", "export"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Form", "記錄頁面"))
        self.label_11.setText(_translate("Form", "瞬時速度"))
        self.label_10.setText(_translate("Form", "瞬時速度"))
        self.label_12.setText(_translate("Form", "平均速度"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("Form", "結算頁面"))

from pyqtgraph import GraphicsLayoutWidget
